PlatformMetadataPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • PlatformMetadataPlatform
Implementers

Constructors

PlatformMetadataPlatform()
Constructs a PlatformMetadataPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getMetaDataValue(String mateDataName) → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ PlatformMetadataPlatform
The default instance of PlatformMetadataPlatform to use.
getter/setter pair